@@ -1,4 +1,4 @@
-__version__ = "2.3.0"
+__version__ = "2.4.0"
 
 import logging
 
@@ -7,7 +7,7 @@ from .copc import CopcReader, Bounds
 from .errors import LaspyException
 from .laswriter import LasWriter
 from .lasreader import LasReader
-from .lib import LazBackend, convert
+from .lib import LazBackend, DecompressionSelection, convert
 from .lib import create_las as create
 from .lib import mmap_las as mmap
 from .lib import open_las as open
